@@ -3,7 +3,9 @@
  *
  *	Copyright (c) 1997--2023 Martin Mares <mj@ucw.cz>
  *
- *	Can be freely distributed and used under the terms of the GNU GPL.
+ *	Can be freely distributed and used under the terms of the GNU GPL v2+
+ *
+ *	SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #ifndef _PCI_LIB_H
@@ -49,6 +51,7 @@ enum pci_access_type {
   PCI_ACCESS_MMIO_TYPE1,		/* MMIO ports, type 1 */
   PCI_ACCESS_MMIO_TYPE1_EXT,		/* MMIO ports, type 1 extended */
   PCI_ACCESS_ECAM,			/* PCIe ECAM via /dev/mem */
+  PCI_ACCESS_AOS_EXPANSION,		/* AmigaOS Expansion library */
   PCI_ACCESS_MAX
 };
 
@@ -79,16 +82,16 @@ struct pci_access {
   struct pci_param *params;
   struct id_entry **id_hash;		/* names.c */
   struct id_bucket *current_id_bucket;
-  int id_load_failed;
+  int id_load_attempted;
   int id_cache_status;			/* 0=not read, 1=read, 2=dirty */
+  char *id_cache_name;
   struct udev *id_udev;			/* names-hwdb.c */
   struct udev_hwdb *id_udev_hwdb;
   int fd;				/* proc/sys: fd for config space */
   int fd_rw;				/* proc/sys: fd opened read-write */
-  int fd_pos;				/* proc/sys: current position */
   int fd_vpd;				/* sys: fd for VPD */
   struct pci_dev *cached_dev;		/* proc/sys: device the fds are for */
-  void *aux;				/* Auxiliary data for use by the back-end */
+  void *backend_data;			/* Private data of the back end */
 };
 
 /* Initialize PCI access */
@@ -163,7 +166,7 @@ struct pci_dev {
   u8 *cache;				/* Cached config registers */
   int cache_len;
   int hdrtype;				/* Cached low 7 bits of header type, -1 if unknown */
-  void *aux;				/* Auxiliary data for use by the back-end */
+  void *backend_data;			/* Private data for of the back end */
   struct pci_property *properties;	/* A linked list of extra properties */
   struct pci_cap *last_cap;		/* Last capability in the list */
 };
